EasyEventCalendar class

A widget that displays an event calendar.

This widget uses the GetX package for state management and displays a calendar with event dates highlighted. It allows navigation between months and displays the days of the week and dates in a grid format.

Inheritance

Constructors

EasyEventCalendar({Key? key, required List<CalendarEvent> eventDates, required dynamic onDateClick(DateTime dateTime), MaterialColor eventColor = Colors.blue, MaterialColor calenderColor = Colors.green})
Creates an EasyEventCalendar widget.
const

Properties

calenderColor MaterialColor
The color used for the calendar background.
final
controller → CustomCalenderController
no setterinherited
eventColor MaterialColor
The color used to highlight event dates.
final
eventDates List<CalendarEvent>
A list of events to be displayed on the calendar.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDateClick → dynamic Function(DateTime dateTime)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
finalinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited